@@ -17,10 +17,6 @@
 
 package org.apache.doris.flink.sink.writer;
 
-import org.apache.flink.annotation.VisibleForTesting;
-import org.apache.flink.util.Preconditions;
-import org.apache.flink.util.concurrent.ExecutorThreadFactory;
-
 import com.fasterxml.jackson.core.type.TypeReference;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
@@ -29,9 +25,11 @@ import org.apache.doris.flink.exception.DorisException;
 import org.apache.doris.flink.exception.DorisRuntimeException;
 import org.apache.doris.flink.exception.StreamLoadException;
 import org.apache.doris.flink.rest.models.RespContent;
-import org.apache.doris.flink.sink.EscapeHandler;
 import org.apache.doris.flink.sink.HttpPutBuilder;
 import org.apache.doris.flink.sink.ResponseUtil;
+import org.apache.flink.annotation.VisibleForTesting;
+import org.apache.flink.util.Preconditions;
+import org.apache.flink.util.concurrent.ExecutorThreadFactory;
 import org.apache.http.client.methods.CloseableHttpResponse;
 import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
@@ -51,16 +49,15 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.regex.Matcher;
 
+import static org.apache.doris.flink.sink.LoadStatus.FAIL;
 import static org.apache.doris.flink.sink.LoadStatus.LABEL_ALREADY_EXIST;
-import static org.apache.doris.flink.sink.LoadStatus.SUCCESS;
 import static org.apache.doris.flink.sink.ResponseUtil.LABEL_EXIST_PATTERN;
-import static org.apache.doris.flink.sink.writer.LoadConstants.ARROW;
-import static org.apache.doris.flink.sink.writer.LoadConstants.CSV;
-import static org.apache.doris.flink.sink.writer.LoadConstants.FORMAT_KEY;
 import static org.apache.doris.flink.sink.writer.LoadConstants.LINE_DELIMITER_DEFAULT;
 import static org.apache.doris.flink.sink.writer.LoadConstants.LINE_DELIMITER_KEY;
 
-/** load data to doris. */
+/**
+ * load data to doris.
+ **/
 public class DorisStreamLoad implements Serializable {
     private static final Logger LOG = LoggerFactory.getLogger(DorisStreamLoad.class);
     private static final ObjectMapper OBJECT_MAPPER = new ObjectMapper();
@@ -72,26 +69,24 @@ public class DorisStreamLoad implements Serializable {
 
     private String loadUrlStr;
     private String hostPort;
-    private String abortUrlStr;
+    private final String abortUrlStr;
     private final String user;
     private final String passwd;
     private final String db;
     private final String table;
     private final boolean enable2PC;
-    private final boolean enableDelete;
     private final Properties streamLoadProp;
     private final RecordStream recordStream;
-    private volatile Future<CloseableHttpResponse> pendingLoadFuture;
+    private Future<CloseableHttpResponse> pendingLoadFuture;
     private final CloseableHttpClient httpClient;
     private final ExecutorService executorService;
     private boolean loadBatchFirstRecord;
 
-    public DorisStreamLoad(
-            String hostPort,
-            DorisOptions dorisOptions,
-            DorisExecutionOptions executionOptions,
-            LabelGenerator labelGenerator,
-            CloseableHttpClient httpClient) {
+    public DorisStreamLoad(String hostPort,
+                           DorisOptions dorisOptions,
+                           DorisExecutionOptions executionOptions,
+                           LabelGenerator labelGenerator,
+                           CloseableHttpClient httpClient) {
         this.hostPort = hostPort;
         String[] tableInfo = dorisOptions.getTableIdentifier().split("\\.");
         this.db = tableInfo[0];
@@ -103,30 +98,12 @@ public class DorisStreamLoad implements Serializable {
         this.abortUrlStr = String.format(ABORT_URL_PATTERN, hostPort, db);
         this.enable2PC = executionOptions.enabled2PC();
         this.streamLoadProp = executionOptions.getStreamLoadProp();
-        this.enableDelete = executionOptions.getDeletable();
         this.httpClient = httpClient;
-        this.executorService =
-                new ThreadPoolExecutor(
-                        1,
-                        1,
-                        0L,
-                        TimeUnit.MILLISECONDS,
-                        new LinkedBlockingQueue<>(),
-                        new ExecutorThreadFactory("stream-load-upload"));
-        this.recordStream =
-                new RecordStream(
-                        executionOptions.getBufferSize(),
-                        executionOptions.getBufferCount(),
-                        executionOptions.isUseCache());
-        if (streamLoadProp.getProperty(FORMAT_KEY, CSV).equals(ARROW)) {
-            lineDelimiter = null;
-        } else {
-            lineDelimiter =
-                    EscapeHandler.escapeString(
-                                    streamLoadProp.getProperty(
-                                            LINE_DELIMITER_KEY, LINE_DELIMITER_DEFAULT))
-                            .getBytes();
-        }
+        this.executorService = new ThreadPoolExecutor(1, 1,
+                0L, TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(), new ExecutorThreadFactory("stream-load-upload"));
+        this.recordStream = new RecordStream(executionOptions.getBufferSize(), executionOptions.getBufferCount());
+        lineDelimiter = streamLoadProp.getProperty(LINE_DELIMITER_KEY, LINE_DELIMITER_DEFAULT).getBytes();
         loadBatchFirstRecord = true;
     }
 
@@ -134,10 +111,6 @@ public class DorisStreamLoad implements Serializable {
         return db;
     }
 
-    public String getTable() {
-        return table;
-    }
-
     public String getHostPort() {
         return hostPort;
     }
@@ -145,7 +118,6 @@ public class DorisStreamLoad implements Serializable {
     public void setHostPort(String hostPort) {
         this.hostPort = hostPort;
         this.loadUrlStr = String.format(LOAD_URL_PATTERN, hostPort, this.db, this.table);
-        this.abortUrlStr = String.format(ABORT_URL_PATTERN, hostPort, db);
     }
 
     public Future<CloseableHttpResponse> getPendingLoadFuture() {
@@ -154,9 +126,8 @@ public class DorisStreamLoad implements Serializable {
 
     /**
      * try to discard pending transactions with labels beginning with labelSuffix.
-     *
-     * @param labelSuffix the suffix of the stream load.
-     * @param chkID checkpoint id of task.
+     * @param labelSuffix
+     * @param chkID
      * @throws Exception
      */
     public void abortPreCommit(String labelSuffix, long chkID) throws Exception {
@@ -164,10 +135,7 @@ public class DorisStreamLoad implements Serializable {
         LOG.info("abort for labelSuffix {}. start chkId {}.", labelSuffix, chkID);
         while (true) {
             try {
-                // TODO: According to label abort txn. Currently, it can only be aborted based on
-                // txnid,
-                //  so we must first request a streamload based on the label to get the txnid.
-                String label = labelGenerator.generateTableLabel(startChkID);
+                String label = labelGenerator.generateLabel(startChkID);
                 HttpPutBuilder builder = new HttpPutBuilder();
                 builder.setUrl(loadUrlStr)
                         .baseAuth(user, passwd)
@@ -176,20 +144,17 @@ public class DorisStreamLoad implements Serializable {
                         .setLabel(label)
                         .setEmptyEntity()
                         .addProperties(streamLoadProp);
-                RespContent respContent =
-                        handlePreCommitResponse(httpClient.execute(builder.build()));
+                RespContent respContent = handlePreCommitResponse(httpClient.execute(builder.build()));
                 Preconditions.checkState("true".equals(respContent.getTwoPhaseCommit()));
                 if (LABEL_ALREADY_EXIST.equals(respContent.getStatus())) {
                     // label already exist and job finished
                     if (JOB_EXIST_FINISHED.equals(respContent.getExistingJobStatus())) {
-                        throw new DorisException(
-                                "Load status is "
-                                        + LABEL_ALREADY_EXIST
-                                        + " and load job finished, "
-                                        + "change you label prefix or restore from latest savepoint!");
+                        throw new DorisException("Load status is " + LABEL_ALREADY_EXIST + " and load job finished, " +
+                                "change you label prefix or restore from latest savepoint!");
+
                     }
                     // job not finished, abort.
-                    Matcher matcher = LABEL_EXIST_PATTERN.matcher(respContent.getMessage());
+                    Matcher matcher  = LABEL_EXIST_PATTERN.matcher(respContent.getMessage());
                     if (matcher.find()) {
                         Preconditions.checkState(label.equals(matcher.group(1)));
                         long txnId = Long.parseLong(matcher.group(2));
@@ -197,10 +162,7 @@ public class DorisStreamLoad implements Serializable {
                         abortTransaction(txnId);
                     } else {
                         LOG.error("response: {}", respContent.toString());
-                        throw new DorisException(
-                                "Load Status is "
-                                        + LABEL_ALREADY_EXIST
-                                        + ", but no txnID associated with it!");
+                        throw new DorisException("Load Status is " + LABEL_ALREADY_EXIST + ", but no txnID associated with it!");
                     }
                 } else {
                     LOG.info("abort {} for check label {}.", respContent.getTxnId(), label);
@@ -218,14 +180,13 @@ public class DorisStreamLoad implements Serializable {
 
     /**
      * write record into stream.
-     *
      * @param record
      * @throws IOException
      */
-    public void writeRecord(byte[] record) throws IOException {
+    public void writeRecord(byte[] record) throws IOException{
         if (loadBatchFirstRecord) {
             loadBatchFirstRecord = false;
-        } else if (lineDelimiter != null) {
+        } else {
             recordStream.write(lineDelimiter);
         }
         recordStream.write(record);
@@ -236,7 +197,7 @@ public class DorisStreamLoad implements Serializable {
         return recordStream;
     }
 
-    public RespContent handlePreCommitResponse(CloseableHttpResponse response) throws Exception {
+    public RespContent handlePreCommitResponse(CloseableHttpResponse response) throws Exception{
         final int statusCode = response.getStatusLine().getStatusCode();
         if (statusCode == 200 && response.getEntity() != null) {
             String loadResult = EntityUtils.toString(response.getEntity());
@@ -246,12 +207,12 @@ public class DorisStreamLoad implements Serializable {
         throw new StreamLoadException("stream load error: " + response.getStatusLine().toString());
     }
 
-    public RespContent stopLoad(String label) throws IOException {
+    public RespContent stopLoad() throws IOException{
         recordStream.endInput();
-        LOG.info("table {} stream load stopped for {} on host {}", table, label, hostPort);
+        LOG.info("stream load stopped.");
         Preconditions.checkState(pendingLoadFuture != null);
         try {
-            return handlePreCommitResponse(pendingLoadFuture.get());
+           return handlePreCommitResponse(pendingLoadFuture.get());
         } catch (Exception e) {
             throw new DorisRuntimeException(e);
         }
@@ -259,34 +220,29 @@ public class DorisStreamLoad implements Serializable {
 
     /**
      * start write data for new checkpoint.
-     *
-     * @param label the label of Stream Load.
+     * @param label
      * @throws IOException
      */
-    public void startLoad(String label, boolean isResume) throws IOException {
-        loadBatchFirstRecord = !isResume;
+    public void startLoad(String label) throws IOException{
+        loadBatchFirstRecord = true;
         HttpPutBuilder putBuilder = new HttpPutBuilder();
-        recordStream.startInput(isResume);
-        LOG.info("table {} stream load started for {} on host {}", table, label, hostPort);
+        recordStream.startInput();
+        LOG.info("stream load started for {}", label);
         try {
             InputStreamEntity entity = new InputStreamEntity(recordStream);
-            putBuilder
-                    .setUrl(loadUrlStr)
+            putBuilder.setUrl(loadUrlStr)
                     .baseAuth(user, passwd)
                     .addCommonHeader()
-                    .addHiddenColumns(enableDelete)
                     .setLabel(label)
                     .setEntity(entity)
                     .addProperties(streamLoadProp);
             if (enable2PC) {
-                putBuilder.enable2PC();
+               putBuilder.enable2PC();
             }
-            pendingLoadFuture =
-                    executorService.submit(
-                            () -> {
-                                LOG.info("table {} start execute load", table);
-                                return httpClient.execute(putBuilder.build());
-                            });
+            pendingLoadFuture = executorService.submit(() -> {
+                LOG.info("start execute load");
+                return httpClient.execute(putBuilder.build());
+            });
         } catch (Exception e) {
             String err = "failed to stream load data with label: " + label;
             LOG.warn(err, e);
@@ -294,7 +250,7 @@ public class DorisStreamLoad implements Serializable {
         }
     }
 
-    public void abortTransaction(long txnID) throws Exception {
+    private void abortTransaction(long txnID) throws Exception {
         HttpPutBuilder builder = new HttpPutBuilder();
         builder.setUrl(abortUrlStr)
                 .baseAuth(user, passwd)
@@ -307,20 +263,18 @@ public class DorisStreamLoad implements Serializable {
         int statusCode = response.getStatusLine().getStatusCode();
         if (statusCode != 200 || response.getEntity() == null) {
             LOG.warn("abort transaction response: " + response.getStatusLine().toString());
-            throw new DorisRuntimeException(
-                    "Fail to abort transaction " + txnID + " with url " + abortUrlStr);
+            throw new DorisRuntimeException("Fail to abort transaction " + txnID + " with url " + abortUrlStr);
         }
 
         ObjectMapper mapper = new ObjectMapper();
         String loadResult = EntityUtils.toString(response.getEntity());
-        Map<String, String> res =
-                mapper.readValue(loadResult, new TypeReference<HashMap<String, String>>() {});
-        if (!SUCCESS.equals(res.get("status"))) {
+        Map<String, String> res = mapper.readValue(loadResult, new TypeReference<HashMap<String, String>>(){});
+        if (FAIL.equals(res.get("status"))) {
             if (ResponseUtil.isCommitted(res.get("msg"))) {
-                throw new DorisException(
-                        "try abort committed transaction, " + "do you recover from old savepoint?");
+                throw new DorisException("try abort committed transaction, " +
+                        "do you recover from old savepoint?");
             }
-            LOG.warn("Fail to abort transaction. txnId: {}, error: {}", txnID, res.get("msg"));
+            LOG.warn("Fail to abort transaction. error: {}", res.get("msg"));
         }
     }
 
