@@ -14,7 +14,6 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
-
 package org.apache.doris.flink.table;
 
 import org.apache.doris.flink.cfg.DorisExecutionOptions;
@@ -119,17 +118,37 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
             .defaultValue(DORIS_EXEC_MEM_LIMIT_DEFAULT)
             .withDescription("");
     // flink write config options
-    private static final ConfigOption<Integer> SINK_BUFFER_FLUSH_MAX_ROWS = ConfigOptions
-            .key("sink.batch.size")
+    private static final ConfigOption<Boolean> SINK_ENABLE_2PC = ConfigOptions
+            .key("sink.enable-2pc")
+            .booleanType()
+            .defaultValue(true)
+            .withDescription("enable 2PC while loading");
+
+    private static final ConfigOption<Integer> SINK_CHECK_INTERVAL = ConfigOptions
+            .key("sink.check-interval")
             .intType()
-            .defaultValue(100)
-            .withDescription("the flush max size (includes all append, upsert and delete records), over this number" +
-                    " of records, will flush data. The default value is 100.");
+            .defaultValue(10000)
+            .withDescription("check exception with the interval while loading");
     private static final ConfigOption<Integer> SINK_MAX_RETRIES = ConfigOptions
             .key("sink.max-retries")
             .intType()
             .defaultValue(3)
             .withDescription("the max retry times if writing records to database failed.");
+    private static final ConfigOption<Integer> SINK_BUFFER_SIZE = ConfigOptions
+            .key("sink.buffer-size")
+            .intType()
+            .defaultValue(256 * 1024)
+            .withDescription("the buffer size to cache data for stream load.");
+    private static final ConfigOption<Integer> SINK_BUFFER_COUNT = ConfigOptions
+            .key("sink.buffer-count")
+            .intType()
+            .defaultValue(3)
+            .withDescription("the buffer count to cache data for stream load.");
+    private static final ConfigOption<String> SINK_LABEL_PREFIX = ConfigOptions
+            .key("sink.label-prefix")
+            .stringType()
+            .noDefaultValue()
+            .withDescription("the unique label prefix.");
     private static final ConfigOption<Duration> SINK_BUFFER_FLUSH_INTERVAL = ConfigOptions
             .key("sink.batch.interval")
             .durationType()
@@ -141,12 +160,12 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
             .booleanType()
             .defaultValue(true)
             .withDescription("whether to enable the delete function");
-    private static final ConfigOption<Long> SINK_BUFFER_FLUSH_MAX_BYTES = ConfigOptions
-            .key("sink.batch.bytes")
-            .longType()
-            .defaultValue(DorisExecutionOptions.DEFAULT_MAX_BATCH_BYTES)
-            .withDescription("the flush max bytes (includes all append, upsert and delete records), over this number" +
-                    " in batch, will flush data. The default value is 10MB.");
+
+    private static final ConfigOption<Boolean> SOURCE_USE_OLD_API = ConfigOptions
+            .key("source.use-old-api")
+            .booleanType()
+            .defaultValue(false)
+            .withDescription("Whether to read data using the new interface defined according to the FLIP-27 specification,default false");
 
     @Override
     public String factoryIdentifier() {
@@ -181,11 +200,16 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
         options.add(DORIS_BATCH_SIZE);
         options.add(DORIS_EXEC_MEM_LIMIT);
 
-        options.add(SINK_BUFFER_FLUSH_MAX_ROWS);
+        options.add(SINK_CHECK_INTERVAL);
+        options.add(SINK_ENABLE_2PC);
         options.add(SINK_MAX_RETRIES);
         options.add(SINK_BUFFER_FLUSH_INTERVAL);
         options.add(SINK_ENABLE_DELETE);
-        options.add(SINK_BUFFER_FLUSH_MAX_BYTES);
+        options.add(SINK_LABEL_PREFIX);
+        options.add(SINK_BUFFER_SIZE);
+        options.add(SINK_BUFFER_COUNT);
+
+        options.add(SOURCE_USE_OLD_API);
         return options;
     }
 
@@ -231,18 +255,23 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
                 .setRequestConnectTimeoutMs(readableConfig.get(DORIS_REQUEST_CONNECT_TIMEOUT_MS))
                 .setRequestReadTimeoutMs(readableConfig.get(DORIS_REQUEST_READ_TIMEOUT_MS))
                 .setRequestRetries(readableConfig.get(DORIS_REQUEST_RETRIES))
-                .setRequestTabletSize(readableConfig.get(DORIS_TABLET_SIZE));
+                .setRequestTabletSize(readableConfig.get(DORIS_TABLET_SIZE))
+                .setUseOldApi(readableConfig.get(SOURCE_USE_OLD_API));
         return builder.build();
     }
 
     private DorisExecutionOptions getDorisExecutionOptions(ReadableConfig readableConfig, Properties streamLoadProp) {
         final DorisExecutionOptions.Builder builder = DorisExecutionOptions.builder();
-        builder.setBatchSize(readableConfig.get(SINK_BUFFER_FLUSH_MAX_ROWS));
+        builder.setCheckInterval(readableConfig.get(SINK_CHECK_INTERVAL));
         builder.setMaxRetries(readableConfig.get(SINK_MAX_RETRIES));
-        builder.setBatchIntervalMs(readableConfig.get(SINK_BUFFER_FLUSH_INTERVAL).toMillis());
+        builder.setBufferSize(readableConfig.get(SINK_BUFFER_SIZE));
+        builder.setBufferCount(readableConfig.get(SINK_BUFFER_COUNT));
+        builder.setLabelPrefix(readableConfig.get(SINK_LABEL_PREFIX));
         builder.setStreamLoadProp(streamLoadProp);
-        builder.setEnableDelete(readableConfig.get(SINK_ENABLE_DELETE));
-        builder.setMaxBatchBytes(readableConfig.get(SINK_BUFFER_FLUSH_MAX_BYTES));
+        builder.setDeletable(readableConfig.get(SINK_ENABLE_DELETE));
+        if (!readableConfig.get(SINK_ENABLE_2PC)) {
+            builder.disable2PC();
+        }
         return builder.build();
     }
 
@@ -260,7 +289,10 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
 
     @Override
     public DynamicTableSink createDynamicTableSink(Context context) {
-        final FactoryUtil.TableFactoryHelper helper = FactoryUtil.createTableFactoryHelper(this, context);
+        final FactoryUtil.TableFactoryHelper helper =
+                FactoryUtil.createTableFactoryHelper(
+                        this, context);
+
         // validate all options
         helper.validateExcept(STREAM_LOAD_PROP_PREFIX);
 
@@ -275,4 +307,4 @@ public final class DorisDynamicTableFactory implements DynamicTableSourceFactory
                 physicalSchema
         );
     }
-}
\ No newline at end of file
+}
